diff src/syntax.c @ 3152:b85f5d7d9d82

[xemacs-hg @ 2005-12-18 22:55:51 by aidan] To my embarrassment, my previous change didn't actually work. This change makes (char-syntax (make-char 'arabic-1-column 50)) give ?w, the expected result after my last change.
author aidan
date Sun, 18 Dec 2005 22:55:52 +0000
parents 141c2920ea48
children 2b8bb4938bb4
line wrap: on
line diff
--- a/src/syntax.c	Sun Dec 18 22:51:14 2005 +0000
+++ b/src/syntax.c	Sun Dec 18 22:55:52 2005 +0000
@@ -613,7 +613,7 @@
 {
   *multi_p_out = 1;
   /* !!#### get this right */
-  return Spunct;
+  return Sword;
 }
 
 #endif
@@ -2296,8 +2296,8 @@
   if (!EQ (table, Vstandard_syntax_table) && !NILP (Vstandard_syntax_table))
     map_char_table (Vstandard_syntax_table, &range,
 		    copy_if_not_already_present, LISP_TO_VOID (mirrortab));
-  /* The resetting made the default be Qnil.  Put it back to Spunct. */
-  set_char_table_default (mirrortab, make_int (Spunct));
+  /* The resetting made the default be Qnil.  Put it back to Sword. */
+  set_char_table_default (mirrortab, make_int (Sword));
   XCHAR_TABLE (mirrortab)->dirty = 0;
 }
 
@@ -2419,7 +2419,7 @@
 							Smax);
   staticpro (&Vsyntax_designator_chars_string);
 
-  set_char_table_default (Vstandard_syntax_table, make_int (Spunct));
+  set_char_table_default (Vstandard_syntax_table, make_int (Sword));
 
   for (i = 0; i <= 32; i++)	/* Control 0 plus SPACE */
     Fput_char_table (make_char (i), make_int (Swhitespace),